import 'package:card_swiper/card_swiper.dart';
import 'package:fair/fair.dart';
import 'package:fair_extension/net/fair_net_plugin.dart';
import 'package:flutter/material.dart';

@FairPatch()
class SwiperTemplate extends StatefulWidget {
  const SwiperTemplate({Key? key}) : super(key: key);

  @override
  State<SwiperTemplate> createState() => _SwiperTemplateState();
}

class _SwiperTemplateState extends State<SwiperTemplate> {
  final List<ItemData> _listData = <ItemData>[];
  int _page = 0;

  /// 生命周期回调，函数名不可修改
  void onLoad() {
    requestData();
  }

  /// 生命周期回调，函数名不可修改
  void onUnload() {}

  void requestData() {
    _page++;
    FairNet.requestData(
        method: FairNet.GET,
        url:
            'https://wos2.58cdn.com.cn/DeFazYxWvDti/frsupload/6f8e5d9e196cbaa4a46041928770b187_grid_data.json',
        data: {'page': _page},
        success: (resp) {
          if (resp == null) {
            return;
          }
          var data = resp['data'];
          data.forEach((item) {
            var dataItem = ItemData();
            try {
              dataItem.picUrl = item['imagePath'];
            } catch (e) {}
            _listData.add(dataItem);
          });
          setState(() {});
        });
  }

  bool isDataEmpty() {
    return _listData.isEmpty;
  }

  int dataLength() {
    return _listData.length;
  }

  String getBannerIcon(int index) {
    return _listData[index].picUrl;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Swiper模版'),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: requestData,
        child: Icon(Icons.add),
      ),
      body: Sugar.ifEqualBool(isDataEmpty(),
          trueValue: () => Center(
                child: Text(
                  '加载中...',
                ),
              ),
          falseValue: () => Container(
                padding: const EdgeInsets.only(
                    left: 20, top: 0, right: 20, bottom: 20),
                child: AspectRatio(
                  // 配置宽高比
                  aspectRatio: 2.5,
                  child: Swiper(
                    itemBuilder: Sugar.indexedWidgetBuilder(
                        (context, index) => Image.network(
                              getBannerIcon(index),
                              width: 50,
                              height: 50,
                            )),
                    // 配置图片数量
                    itemCount: dataLength(),
                    // 底部分页器
                    pagination: null,
                    // 左右箭头
                    control: null,
                    // 无限循环
                    loop: true,
                    // 自动轮播
                    autoplay: true,
                  ),
                ),
              )),
    );
  }
}

class ItemData extends Object {
  String picUrl = '';
}
